import logging
from numbers import Complex
from pathlib import Path

from xmlschema import *

from .type_mapping import *

log = logging.getLogger()

mappings = [
    XSDNativeSimpleTypeMapping(),
    ChoiceMapping(),
    SequenceMapping(),
]

def translate_schema (schema_path, schema_id, schema_locations = []):
    js = {
        "$id" : schema_id,
        "$defs" : {}
    }

    logging.info(f"Translating schema {schema_path}")
    xs = XMLSchema(schema_path, validation='lax', locations=schema_locations)
    logging.info(f"Schema namespace: {xs.target_namespace}" )

    for type_name, xsd_type in xs.types.items():
        logging.info(f"Processing {type_name} : {xsd_type}")

        j = None
        for mapping in mappings:
            log.debug("\n----------------------------------------")
            j = mapping.map(xsd_type)
            if j is None:
                continue
            else:
                break
        if j is None:
            raise Exception(f"Unmapped type {type_name} ({xsd_type})")
        js["$defs"][xsd_type.local_name] = j
        logging.debug (f"Mapped {type_name} to {j}")
    return js