import re

from xmlschema import *

def extract_namespace(qname: str):
    match = re.search(r'^\{([^\{\}]+)\}(([^\{\}]+))$', qname)
    if match is None:
        return None
    return match.group(1)

NS_MAP = {
    'http://uri.etsi.org/03120/common/2019/10/Core' : 'core.json',
    'http://uri.etsi.org/03120/common/2016/02/Common' : 'common.json',
    'http://uri.etsi.org/03280/common/2017/07' : 'etsi103280.json',
    'http://www.w3.org/2000/09/xmldsig#' : 'xmldsig',
}

def get_ref_for(xsd_type: XsdType, current_ns : str):
    ns = extract_namespace(xsd_type.name)
    if ns == current_ns:
        return { "$ref" : f"#/$defs/{xsd_type.local_name}" }
    else:
        mapped_id = NS_MAP[ns]
        return { "$ref" : f"{mapped_id}#/$defs/{xsd_type.local_name}"}